pub enum LinuxFileAccess {
Read,
Write,
ReadWrite,
}Expand description
Access requested for one opened Linux file handle.
Variants
Read
The handle reads the revision-bound remote snapshot only.
Write
The handle writes durable local generations and does not permit reads.
ReadWrite
The handle reads and writes the durable local staging session.