spawn_mount_read_only

Function spawn_mount_read_only 

pub fn spawn_mount_read_only<B>(
    filesystem: LinuxReadOnlyFilesystem<B>,
    mountpoint: impl AsRef<Path>,
    config: &LinuxMountConfig,
) -> Result<LinuxBackgroundSession>
where B: CloudFilesBackend + 'static,
Spawns a read-only FUSE session and returns its kernel invalidation lifecycle handle.

Errors

Returns an error when the mountpoint cannot be opened or the background FUSE session cannot be started.