LinuxCreateFileAcceptance

Struct LinuxCreateFileAcceptance 

pub struct LinuxCreateFileAcceptance { /* private fields */ }
Complete durable acceptance returned before FUSE reports create success.

Implementations

Source

impl LinuxCreateFileAcceptance

pub const fn new(created: LinuxCreatedFile, session: LinuxWriteSession) -> Self

Creates an acceptance containing durable namespace, mutation, and staging state.

pub const fn created(&self) -> &LinuxCreatedFile

Returns the durable local namespace allocation.

pub const fn session(&self) -> &LinuxWriteSession

Returns the empty local staging session opened by the transaction.

pub fn into_parts(self) -> (LinuxCreatedFile, LinuxWriteSession)

Consumes the acceptance into the durable record and opened staging session.