LinuxNamespaceOverlay

Struct LinuxNamespaceOverlay 

pub struct LinuxNamespaceOverlay { /* private fields */ }
Restored local namespace state not represented by the legacy regular-file create list.

Implementations

Source

impl LinuxNamespaceOverlay

pub const fn new( items: Vec<LinuxNamespaceItem>, tombstones: Vec<LinuxNamespaceTombstone>, ) -> Self

Creates a restart overlay from current local entries and deletion markers.

pub fn items(&self) -> &[LinuxNamespaceItem]

Returns current local namespace entries.

pub fn tombstones(&self) -> &[LinuxNamespaceTombstone]

Returns current local deletion markers.

pub fn into_parts( self, ) -> (Vec<LinuxNamespaceItem>, Vec<LinuxNamespaceTombstone>)

Consumes the overlay into its durable collections.