pub fn spawn_mount_read_only<B>(
filesystem: LinuxReadOnlyFilesystem<B>,
mountpoint: impl AsRef<Path>,
config: &LinuxMountConfig,
) -> Result<LinuxBackgroundSession>where
B: CloudFilesBackend + 'static,Expand description
Spawns a read-only FUSE session and returns its kernel invalidation lifecycle handle.
Errors
Returns an error when the mountpoint cannot be opened or the background FUSE session cannot be started.