pub struct LinuxCreateFileAcceptance { /* private fields */ }Expand description
Complete durable acceptance returned before FUSE reports create success.
Implementations
Sourceimpl LinuxCreateFileAcceptance
impl LinuxCreateFileAcceptance
Sourcepub const fn new(created: LinuxCreatedFile, session: LinuxWriteSession) -> Self
pub const fn new(created: LinuxCreatedFile, session: LinuxWriteSession) -> Self
Creates an acceptance containing durable namespace, mutation, and staging state.
Sourcepub const fn created(&self) -> &LinuxCreatedFile
pub const fn created(&self) -> &LinuxCreatedFile
Returns the durable local namespace allocation.
Sourcepub const fn session(&self) -> &LinuxWriteSession
pub const fn session(&self) -> &LinuxWriteSession
Returns the empty local staging session opened by the transaction.
Sourcepub fn into_parts(self) -> (LinuxCreatedFile, LinuxWriteSession)
pub fn into_parts(self) -> (LinuxCreatedFile, LinuxWriteSession)
Consumes the acceptance into the durable record and opened staging session.