pub struct LinuxRemoteDelete { /* private fields */ }Expand description
Exact durable facts for one remote deletion or destination replacement.
Implementations
Sourceimpl LinuxRemoteDelete
impl LinuxRemoteDelete
Sourcepub fn new(
key: CloudItemKey,
inode_record: LinuxInodeRecord,
parent_key: CloudItemKey,
name: impl Into<String>,
kind: LinuxNodeKind,
) -> Result<Self>
pub fn new( key: CloudItemKey, inode_record: LinuxInodeRecord, parent_key: CloudItemKey, name: impl Into<String>, kind: LinuxNodeKind, ) -> Result<Self>
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
pub const fn key(&self) -> &CloudItemKey
pub const fn inode_record(&self) -> &LinuxInodeRecord
pub const fn parent_key(&self) -> &CloudItemKey
pub fn name(&self) -> &str
pub const fn kind(&self) -> LinuxNodeKind