pub struct LinuxRenameRequest { /* private fields */ }Expand description
Native facts for one rename or move that preserves stable item identity.
Implementations
Sourceimpl LinuxRenameRequest
impl LinuxRenameRequest
Sourcepub fn new(
key: CloudItemKey,
inode_generation: LinuxInodeGeneration,
kind: LinuxNodeKind,
old_parent_key: CloudItemKey,
old_name: impl Into<String>,
new_parent_key: CloudItemKey,
new_name: impl Into<String>,
destination: Option<LinuxRenameDestination>,
no_replace: bool,
session_generation: SessionGeneration,
) -> Result<Self>
pub fn new( key: CloudItemKey, inode_generation: LinuxInodeGeneration, kind: LinuxNodeKind, old_parent_key: CloudItemKey, old_name: impl Into<String>, new_parent_key: CloudItemKey, new_name: impl Into<String>, destination: Option<LinuxRenameDestination>, no_replace: bool, session_generation: SessionGeneration, ) -> Result<Self>
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
pub const fn key(&self) -> &CloudItemKey
pub const fn inode_generation(&self) -> LinuxInodeGeneration
pub const fn kind(&self) -> LinuxNodeKind
pub const fn old_parent_key(&self) -> &CloudItemKey
pub fn old_name(&self) -> &str
pub const fn new_parent_key(&self) -> &CloudItemKey
pub fn new_name(&self) -> &str
pub const fn destination(&self) -> Option<&LinuxRenameDestination>
pub const fn no_replace(&self) -> bool
pub const fn session_generation(&self) -> SessionGeneration