pub struct LinuxWriteCommit { /* private fields */ }Expand description
Result of one durably accepted write, truncate, flush, or fsync operation.
Implementations
Sourceimpl LinuxWriteCommit
impl LinuxWriteCommit
Sourcepub const fn new(snapshot: LocalContentSnapshot) -> Self
pub const fn new(snapshot: LocalContentSnapshot) -> Self
Creates a commit backed by one immutable local generation.
Sourcepub const fn snapshot(&self) -> &LocalContentSnapshot
pub const fn snapshot(&self) -> &LocalContentSnapshot
Returns the immutable dirty snapshot that is safe for upload recovery.
Sourcepub fn into_snapshot(self) -> LocalContentSnapshot
pub fn into_snapshot(self) -> LocalContentSnapshot
Consumes the commit into its immutable snapshot.