pub struct LinuxWriteSession { /* private fields */ }Expand description
Product-owned durable staging session returned after the base bytes are installed.
Implementations
Sourceimpl LinuxWriteSession
impl LinuxWriteSession
Sourcepub const fn new(
id: LinuxWriteSessionId,
key: CloudItemKey,
size: u64,
session_generation: SessionGeneration,
) -> Self
pub const fn new( id: LinuxWriteSessionId, key: CloudItemKey, size: u64, session_generation: SessionGeneration, ) -> Self
Creates a staging session response.
Sourcepub fn from_recovered(
id: LinuxWriteSessionId,
snapshot: LocalContentSnapshot,
session_generation: SessionGeneration,
) -> Self
pub fn from_recovered( id: LinuxWriteSessionId, snapshot: LocalContentSnapshot, session_generation: SessionGeneration, ) -> Self
Creates a session reopened from one immutable durable dirty snapshot.
Sourcepub const fn id(&self) -> &LinuxWriteSessionId
pub const fn id(&self) -> &LinuxWriteSessionId
Returns the opaque product-owned session identity.
Sourcepub const fn session_generation(&self) -> SessionGeneration
pub const fn session_generation(&self) -> SessionGeneration
Returns the mount session generation bound to this writeback session.